#!/bin/bash
## Indicamos el usuario con que queremos que inicie de manera automatica

USER=$(whoami)
ACTUAL=$(cat /etc/lightdm/lightdm.conf | grep autologin-user | cut -d "=" -f2)
TEXTO1="  Actualmente el equipo inicia sesión automática con el usuario: <b>$(echo $ACTUAL | cut -d' ' -f1)</b>  \n\n  Selecciona el Usuario con quien deseas que el equipo inicie <b>Sesión de manera Automática</b>:  "
TEXTO2="  Actualmente el equipo <b>NO</b> inicia Sesión Automática con ningún usuario.  \n\n  Selecciona el Usuario con quien deseas que el equipo inicie <b>Sesión de manera Automática</b>:  "
USERDEFINITIVO=""

function configurar-usuario-inicio-automatico-lightdm {

	USERDEFINITIVO="$1"
	if test "$1" != "usuario-ldap" ; then
		if grep "autologin-user" /etc/lightdm/lightdm.conf ; then
			sed --follow-symlinks -i "s/.*autologin-user=.*/autologin-user=$1/g" /etc/lightdm/lightdm.conf
		else
			echo "autologin-user=$1" >> /etc/lightdm/lightdm.conf
		fi
	else
# Si el usuario que va a iniciar sesión es de LDAP quitaremos el autologin y esconderemos usuarios locales
	if grep autologin-user /etc/lightdm/lightdm.conf ; then
		sed -i "s/autologin-user=.*/#&/g" /etc/lightdm/lightdm.conf
	fi

	if grep greeter-hide-users /etc/lightdm/lightdm.conf ; then
		if grep "#greeter-hide-users=" /etc/lightdm/lightdm.conf ; then
			sed -i "s/#greeter-hide-users.*/greeter-hide-users=true/g" /etc/lightdm/lightdm.conf
		else
			sed -i "s/greeter-hide-users.*/greeter-hide-users=true/g" /etc/lightdm/lightdm.conf
		fi
	else
		echo "greeter-hide-users=true" >> /etc/lightdm/lightdm.conf
	fi

	fi
}

function crear-usuario {
TEXTO="  Se va a crear un usuario para que inicie sesión automática  \n\
   Ten en cuenta los siguientes aspectos:   \n\n\
   1.- El nombre del usuario no debe tener espacios en blanco \n\
   2.- No utilizes mayúsculas para el nombre \n\
   3.- Puedes usar números \n"
	DATOS=$(yad --center --width 400 \
	--window-icon=/usr/share/lxpanel/images/vitalinux.svg \
	--image=/usr/share/lxpanel/images/usuario.png \
	--title "Inicio de Sesión Automático" \
	--text-align center --justify="center" \
	--text "$TEXTO" \
	--form \
	--field="Nombre de Usuario" \
	--field="Password":H \
	--button="gtk-ok:0" --button="gtk-cancel:1")
	NOMBRE=$(echo $DATOS | cut -d"|" -f1)
	PASS=$(echo $DATOS | cut -d"|" -f2)
	if ! grep "^$NOMBRE:" /etc/passwd && useradd -m -d /home/$NOMBRE \
		-s /bin/bash -p $(printf "$PASS" | mkpasswd -s -m md5) \
		-c "Usuario Creado para Inicio de Sesión Automática" $NOMBRE ; then
		configurar-usuario-inicio-automatico-lightdm $NOMBRE
		if yad --center --width 500 \
			--window-icon=/usr/share/lxpanel/images/vitalinux.svg \
			--title "Inicio de Sesión Automático" \
			--text-align center \
			--image=/usr/share/lxpanel/images/usuario.png \
			--text "   ¿¿Te gustaría que el usuario <b>$NOMBRE</b>   \n    fuera <b>administrador</b> del equipo??   " \
			--button="Si, <b>$NOMBRE</b> Administrador":0 --button="No":1 ; then
			/usr/sbin/usermod -aG adm,cdrom,sudo,dip,plugdev,lpadmin,sambashare $NOMBRE
		fi
	else
		yad --center --width 500 \
		--window-icon=/usr/share/lxpanel/images/vitalinux.svg \
		--title "Inicio de Sesión Automático" \
		--text-align center \
		--image=/usr/share/lxpanel/images/usuario.png \
		--text "¡¡El usuario $NOMBRE ya existe!!" \
		--button="Continuar":0
		crear-usuario
	fi
	
}

function decidir-usuario-inicio-sesion {
	USUARIO=$(yad --center --width 500 \
	--window-icon=/usr/share/lxpanel/images/vitalinux.svg \
	--title "Inicio de Sesión Automático" \
	--text-align center \
	--image=/usr/share/lxpanel/images/usuario.png \
	--entry \
	--text "$1" \
	--entry-text \
	"Sin-Inicio-Sesion-Automático" \
	"Usuario Nuevo a Crear" \
	$(awk -F ":" '{if ( $3 > 999 && $6~/\/home\/.*/) {print $1}}' /etc/passwd) \
	"Usuario LDAP" \
	--button="gtk-ok:0" --button="gtk-cancel:1")

	if test $? -eq 1 ; then
		exit 0
	fi

	if test "$USUARIO" == "Usuario Nuevo a Crear" ; then
		crear-usuario
	else
		configurar-usuario-inicio-automatico-lightdm "$USUARIO"
	fi
}

if [ -f $_FIRST ] ; then

	if cat /etc/lightdm/lightdm.conf | grep autologin-user ; then
		decidir-usuario-inicio-sesion "$TEXTO1"
	else
		decidir-usuario-inicio-sesion "$TEXTO2"
	fi

	if test $? -eq 0 ; then
		yad --center --title "Hecho!!" \
		--text-align center \
		--text " Ya se ha configurado el usuario de Inicio de Sesión Automático: <b>$USERDEFINITIVO</b> \n Debe <b>REINICIAR el EQUIPO</b> para verificarlo." \
		--button="gtk-ok:0"
	fi

fi
